% exp03_setup.m
% This script loads the Matlab workspace with the variables needed for the
% Simulink models exp03_Simulink and exp03_SRV02 to run.  

%% Filter Parameters
% High-pass filter in PD control used to compute velocity
% Cutoff frequency (rad/s)
wcf = 2 * pi * 50.0;
% Damping ratio
zetaf = 0.9;
% Encoder high-pass filter used to compute velocity
% Cutoff frequency (rad/s)
wcf_e = 2 * pi * 50.0;
% Damping ratio
zetaf_e = 0.9;
%
%% Sets sensor and amplifier calibration gains.
    % Potentiometer Sensitivity (rd/V)
    K_POT = -(352 * pi / 180 / 10);
    % Tachometer Sensitivity (rd/s/V)
    Kg = 70;
    K_TACH = -(1000 * 2 * pi / 60 / 1.5 / Kg);
    % Encoder Resolution, for a quadrature encoder, (rd/count)
    K_ENC = 2 * pi / ( 4 * 1024 );
    
%% SRV02 Configuration
    % Digital-to-Analog Maximum Voltage (V)
    VMAX_DAC = 10;
    % Amplifier Gain: set VoltPAQ amplifier gain to 1
    K_AMP = 1;
    % Set the amplifier Maximum Output Voltage (V) and Output Current (A)
    VMAX_AMP = 24;
    IMAX_AMP = 4;
    
%% Steady state gain and time constant
    K = 1.53;   % Using approximate values.  Adjust if desired.
    tau = 0.0254;   % Using approximate values.  Adjust if desired.
    clc
    message = sprintf('\nSteady-state gain and time constant are set to...\n');
    disp(message);
    disp( [ '   K = ' num2str( K, 3 ) ' rad/s/V' ] )
    disp( [ '   tau = ' num2str( tau, 3 ) ' s' ] )
    
%% Define Controller Gains
    Kp = 07.82;
    Kv = -0.157;
    Ki = 0;
    message = sprintf('\n\nController gains are set to...\n');
    disp(message);
    disp( [ '   Kp = ' num2str( Kp, 3 ) ] )
    disp( [ '   Kv = ' num2str( Kv, 3 )  ] )
    
    